<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name></name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <source>Arora is already running. Exiting.</source>
        <translation type="obsolete">Arora läuft bereits.</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Über</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>leichtgewichtiger WebKit-basierter Webbrowser</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;￼&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;￼p, li { white-space: pre-wrap; }￼&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;￼&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>WebKit Version: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Sprachen</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Sprachen: bevorzugte Reihenfolge:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Nach &amp;Oben</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Nach &amp;Unten</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Blockiert durch AdBlockRegel: %1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Benutzerdefinierte Regel hinzufügen</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Weitere Informationen zum Schreiben von Regeln...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Abonnement aktualisieren</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Abonnements anzeigen...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Abonnement entfernen</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>AdBlock Konfiguration</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>AdBlock aktivieren</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Benutzerdefinierte Regeln</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Regel</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>Abonnieren?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>Wollen sie dieses AdBlock Abonnement hinzufügen?
%1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Geben Sie einen Namen und Speicherort für das Lesezeichen an.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Formular Passwörter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Alle löschen</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;Möchten Sie dieses Passwort speichern?&lt;/b&gt;&lt;br&gt;         Um die gespeicherte Passwörter anzuzeigen oder zu löschen, nutzen Sie das Autovervollständigungs-Tab im Einstellungsmenü.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Nie für diese Seite</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Nicht jetzt</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Benutzername</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>In einem neuen tab öffnen</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Titel editieren</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Adresse editieren</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Fehler beim Laden der Lesezeichen in Zeile %1, Spalte %2￼:
%3</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Lesezeichenleiste</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Lesezeichenmenü</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Lesezeichenleiste</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importiert %1</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml *.html)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml *.html)</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Fehler beim Laden der html Lesezeichen: %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Exportfehler</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Fehler beim Speichern der Lesezeichen</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Lesezeichen entfernen</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Lesezeichen einfügen</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Namensänderung</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Adressänderung</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Namensänderung</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Adressänderung</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>XBEL Lesezeichen</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>HTML Netscape Lesezeichen</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>htmlToXbel wird benötigt</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>htmlToXBel - welches mit Arora vertrieben wird und nötig ist um HTML Lesezeichen zu importieren - ist nicht installiert oder nicht im Suchpfad verfügbar.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Lade Lesezeichen</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Fehler beim Laden der HTML Lesezeichen: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>In Tabs öffnen</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Lesezeichen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>In einem neuen &amp;Tab öffnen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Lesezeichen hinzufügen...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Ordner hinzufügen...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Lesezeichen</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>%1 Fenster und %2 Tabs sind geöffnet
Arora wirklich beenden?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Wiederherstellung fehlgeschlagen</translation>
    </message>
    <message>
        <source>The saved session will not being restored because last time it was restored Arora crashed.</source>
        <translation type="obsolete">Die gespeicherte Sitzung wird nicht wiederhergestellt weil bei der letzten Wiederherstellung Arora abgestürzt ist.</translation>
    </message>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(Änderung: %1 %2)</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Die gespeicherte Sitzung wird nicht wiederhergestellt, weil bei der letzten Wiederherstellung Arora abgestürzt ist.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Arora ist bei dem Versuch die Sitzung wiederherzustellen abgestürzt. Soll erneut versucht werden, die Sitzung wiederherzustellen?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Neues Fenster</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Datei öffnen...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>&amp;Adresse aufrufen...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Speichern unter...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>Lesezeichen &amp;importieren...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>Lesezeichen &amp;exportieren...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Druck&amp;vorschau...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drucken...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Private Browsing...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Wiederholen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Einfügen</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Über&amp;%1</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translatorcomment>Not sure if the Key is the same in german</translatorcomment>
        <translation>Strg+Y</translation>
    </message>
    <message>
        <source>&amp;Find Next</source>
        <translation type="obsolete">Nächstes &amp;Ergebnis</translation>
    </message>
    <message>
        <source>&amp;Find Previous</source>
        <translation type="obsolete">Vorheriges &amp;Ergebnis</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="obsolete">&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Strg+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Strg+B</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Strg+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Strg+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <translation type="obsolete">Seite aktualisieren</translation>
    </message>
    <message>
        <source>&amp;Make Text Bigger</source>
        <translation type="obsolete">&amp;Text vergrößern</translation>
    </message>
    <message>
        <source>&amp;Make Text Normal</source>
        <translation type="obsolete">Normale &amp;Textgröße</translation>
    </message>
    <message>
        <source>&amp;Make Text Smaller</source>
        <translation type="obsolete">&amp;Text verkleinern</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;Quelltext</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Strg+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Verlauf</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Startseite</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Letzte Sitzung wiederherstellen</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Lesezeichen</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Lesezeichen verwalten...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Lesezeichen hinzufügen...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Ordner hinzufügen...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>Web&amp;suche</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Strg+K</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">&amp;Netzwerk Monitor anzeigen</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Web-&amp;Inspector aktivieren</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">Über &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Statusleiste zeigen</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Statusleiste verbergen</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Werkzeugleiste zeigen</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Werkzeugleiste verbergen</translation>
    </message>
    <message>
        <source>Show Bookmarks bar</source>
        <translation type="obsolete">Lesezeichenleiste zeigen</translation>
    </message>
    <message>
        <source>Hide Bookmarks bar</source>
        <translation type="obsolete">Lesezeichenleiste verbergen</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Webinhalte öffnen</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Webinhalte (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Dokument drucken</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Private Browsing wirklich aktivieren?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Wenn Private Browsing aktiviert ist, werden einige Funktionen deaktiviert die Ihre Privatsphäre betreffen:&lt;ul&gt;&lt;li&gt; Aufgerufene Webseiten erscheinen nicht im Verlauf.&lt;/li&gt;&lt;li&gt; Einträge im Downloadfenster werden automatisch entfernt.&lt;/li&gt;&lt;li&gt; Neue Cookies werden nicht gespeichert, auf bestehende Cookies gibt es keinen Zugriff.&lt;/li&gt;&lt;li&gt; Seitensymbole und Sitzungen werden nicht gespeichert.&lt;/li&gt;&lt;li&gt; Suchen erscheinen nicht im Suchverlauf.&lt;/li&gt;&lt;/ul&gt;Die Zurück- und Vorwärtsbuttons funktionieren noch auf offenen Webseiten bis das Fenster geschlossen wird.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Soll das Fenster wirklich geschlossen werden? Es sind %1 Tabs geöffnet</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation type="obsolete">Quelltext von %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Web Inspector</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Der Web Inspector funktioniert nur auf neu geladenen Seiten.
Sollen alle Seiten neu geladen werden?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Ladevorgang abbrechen</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Seite aktualisieren</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Strg+L</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttonsto return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Wenn Private Browsing aktiviert ist, werden einige Funktionen deaktiviert die Ihre Privatsphäre betreffen:&lt;ul&gt;&lt;li&gt; Aufgerufene Webseiten erscheinen nicht im Verlauf.&lt;/li&gt;&lt;li&gt; Einträge im Downloadfenster werden automatisch entfernt.&lt;/li&gt;&lt;li&gt; Neue Cookies werden nicht gespeichert, auf bestehende Cookies gibt es keinen Zugriff.&lt;/li&gt;&lt;li&gt; Seitensymbole und Sitzungen werden nicht gespeichert.&lt;/li&gt;&lt;li&gt; Suchen erscheinen nicht im Suchverlauf.&lt;/li&gt;&lt;/ul&gt;Die Zurück- und Vorwärtsbuttons funktionieren noch auf offenen Webseiten bis das Fenster geschlossen wird.</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>Private Daten &amp;löschen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Wenn Private Browsing aktiviert ist, werden einige Funktionen deaktiviert die Ihre Privatsphäre betreffen:&lt;ul&gt;&lt;li&gt; Aufgerufene Webseiten erscheinen nicht im Verlauf.&lt;/li&gt;&lt;li&gt; Einträge im Downloadfenster werden automatisch entfernt.&lt;/li&gt;&lt;li&gt; Neue Cookies werden nicht gespeichert, auf bestehende Cookies gibt es keinen Zugriff.&lt;/li&gt;&lt;li&gt; Seitensymbole und Sitzungen werden nicht gespeichert.&lt;/li&gt;&lt;li&gt; Suchen erscheinen nicht im Suchverlauf.&lt;/li&gt;&lt;/ul&gt;Die Zurück- und Vorwärtsbuttons funktionieren noch auf offenen Webseiten bis das Fenster geschlossen wird.</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="obsolete">Nächstes &amp;Ergebnis</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>&amp;Vorheriges Ergebnis</translation>
    </message>
    <message>
        <source>Prefe&amp;rences</source>
        <translation type="obsolete">&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>Seite &amp;aktualisieren</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">Text ver&amp;größern</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">&amp;Normale Textgröße</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">Text ver&amp;kleinern</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Lesezeichenleiste zeigen</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Lesezeichenleiste verbergen</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>&amp;Nächstes Ergebnis</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Einstellun&amp;gen...</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Menüleiste zeigen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>&amp;Normale Größe</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Nur &amp;Textgröße ändern</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Alle Lezeichen anzeigen...</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Sprache ändern</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Text Kodierung</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Alle auswählen</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Strg+B</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Optionen...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Suchmaschienen verwalten...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;AdBlock...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Sobald privates Surfen aktiviert ist, sind einige Aktionen die ihre Privatsphäre betreffen deaktiviert:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>Webseiten werden nicht zum Verlauf hinzugefügt.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Objekte werden automatisch aus dem Download Fenster entfernt.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>Neue Cookies werden nicht gespeichert, auf aktuelle Cookies kann nicht zugegriffen werden.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>Website Symbole werden nicht gespeichert.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>Die Sitzung wird nicht gespeichert.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>Suchen werden nicht in den Suchverlauf aufgenommen.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>Kein neuer Netzwerk-Cache wird auf der Platte erstellt.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Bis Sie das Fenster geschlossen haben, können Sie die Zurück und Vorwärts Schaltflächen wie gewohnt benutzen.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Privates Surfen</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Private Daten löschen</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Folgende Einträge löschen:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Seitenverlauf</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>&amp;Downloadverlauf</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>&amp;Suchverlauf</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ache</source>
        <translation type="obsolete">C&amp;ache</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;Webseiten-Symbole</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>&amp;Private Daten löschen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>&amp;Zwischengespeicherte Webseiten</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Alle Laden</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>%1 zur Whitelist hinzufügen</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Von der Whitelist entfernen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Flash laden</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Webseiten auf der Whitelist</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="obsolete">Status</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Erlauben</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blocken</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Für diese Sitzung erlauben</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regel</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Sicher</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Läuft ab am</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Inhalte</translation>
    </message>
    <message>
        <source>true</source>
        <translation>wahr</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falsch</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Sitzungs-Cookie</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>&amp;Alle Cookies entfernen</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Regel hinzufügen</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Cookie Ausnahmen</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Neue Ausnahme</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domain:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blocken</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Für diese Sitzung erlauben</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Erlauben</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Ausnahmen</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;Alle entfernen</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <source>RemoveAll</source>
        <translation></translation>
    </message>
    <message>
        <source>Left:</source>
        <translation></translation>
    </message>
    <message>
        <source>Foo Bar Baz Arora LineEdit Manual Test This is the end</source>
        <translation></translation>
    </message>
    <message>
        <source>Right:</source>
        <translation></translation>
    </message>
    <message>
        <source>Empty:</source>
        <translation></translation>
    </message>
    <message>
        <source>Foo Bar Baz Arora LineEdit Manual Test</source>
        <translation></translation>
    </message>
    <message>
        <source>Widget</source>
        <translation></translation>
    </message>
    <message>
        <source>Site Icon</source>
        <translation></translation>
    </message>
    <message>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Position</source>
        <translation></translation>
    </message>
    <message>
        <source>Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Right</source>
        <translation></translation>
    </message>
    <message>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <source>Swap Visibility</source>
        <translation></translation>
    </message>
    <message>
        <source>Add ToolButton</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Einträge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download abgebrochen: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 von %2 (%3/Sek) - %4</translation>
    </message>
    <message>
        <source>Error opening save file: %1</source>
        <translation type="obsolete">Fehler beim öffnen der gespeicherten Datei: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Fehler beim Speichern: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netzwerk-Fehler: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">Sekunden</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">Minuten</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation type="obsolete">- noch %4 %5</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 von %2 (%3/Sek) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 von %2 - Angehalten</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MB</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Erneut versuchen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- noch %n Minute(n)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- noch %n Sekunden</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Fehler beim Öffnen der Ausgabedatei: %1</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>Download Verzeichnis (%1) konnte nicht erstellt werden.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Es sind noch %1 Download(s) aktiv.
Trotzdem beenden?</translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>noch %n Minute verbleibend</numerusform>
            <numerusform>noch %n Minuten verbleibend</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>noch %n sekunde verbleibend</numerusform>
            <numerusform>noch %n sekunden verbleibend</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>1 Download</source>
        <translation type="obsolete">1 Download</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <translation type="obsolete">%1 Downloads</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Download</numerusform>
            <numerusform>%n Downloads</numerusform>
        </translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Kein Fehler</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Fehler beim Öffnen von %1: Datei oder Verzeichnis nicht gefunden</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Kann %1 nicht lesen</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Inhalt von %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;Alle entfernen</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Kompletten Verlauf zeigen</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Verlauf leeren</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Verlauf leeren...</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Soll der Verlauf geleert werden?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="obsolete">%1 Einträge</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n Einträg</numerusform>
            <numerusform>%n Einträge</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Willkommen bei Arora!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Arora Start</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Suche!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Suchergebnisse werden zur Verfügung gestellt von</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>Über Arora</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>System locale (%1) %2</source>
        <translation type="obsolete">System-Vorgabe (%1) %2</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Standard</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Keine Sprachdateien installiert.</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Sprache wählen</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Sie können eine andere Sprache wählen,&lt;br&gt;als im Betriebssystem voreingestellt.&lt;/p&gt;&lt;p&gt;Bitte wählen Sie die Sprache,&lt;br&gt; die verwendet werden soll</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>In %1 befinden sich keine Übersetzungsdateien.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Benutzernamen und Password eingeben für &quot;%1&quot; bei &quot;%2&quot;&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Mit Proxy &quot;%1&quot; verbinden mit:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - SSL Fehler</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;SSL-Fehler:&lt;br/&gt;&lt;br/&gt;für:&lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Möchten Sie diese Fehler ignorieren?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Möchten Sie all diese Zertifikate akzeptieren?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Zertifikate:&lt;br/&gt;%1&lt;br/&gt;Alle Zertifikate akzeptieren?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">SSL-Fehler:

%1

%2

Möchten Sie diese Fehler ignorieren?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Alle Zertifikate akzeptieren?</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Herausgeber: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Nicht gültig vor: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Gültig bis: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Alternative Namen:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Name</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Wert</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Netzwerk Monitor</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Netzwerkanfragen</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Anfrage Header</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Antwort Header</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Entfernen</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">&amp;Alle Entfernen</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 ist keine gültige OpenSearch 1.1 Beschreibung oder schon in Ihrer Liste.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Mindestens eine Suchmaschiene muss hier eingetragen sein.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>OpenSearch Verwaltung</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>Auf Standard zu&amp;rücksetzen</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Beschreibung:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Stellt Kontextvorschläge bereit&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Mit Kommas getrennte Liste von Schlüsselwörtern die In der Adressleiste von Suchbegriffen gefolgt eingegeben werden können um mit dieser Suchmaschine zu suchen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Schlüsselwörter</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Möchten Sie die folgende Suchmaschiene zu Ihrer Liste hinzufügen?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Sucht mit: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentifikation erforderlich</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Nicht gefunden</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy Authentifikation</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation type="obsolete">ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Zum Proxy verbinden</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Die Datei ist keine XBEL Version 1.0 Datei.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Unbekannter Titel</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Diese Datei ist keine OpenSearch 1.1 Datei.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Umleitung: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Methode</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adresse</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Antwort</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Länge</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Format</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Information</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation type="obsolete">&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="obsolete">&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Alle hervorheben</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Einstellungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Home:</source>
        <translation type="obsolete">Startseite:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Aktuelle Seite</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Verlauf Einträge löschen:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Nach einem Tag</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Nach einer Woche</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Nach zwei Wochen</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Nach einem Monat</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Nach einem Jahr</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Save downloads to:</source>
        <translation type="obsolete">Downloads speichern nach:</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Links von Programmen öffnen in:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">einem Tab im aktuellen Fenster</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>einem neuen Fenster</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aussehen</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Schrift fester Breite:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Sprachen: bevorzugte Reihenfolge für Webseiten:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privatsphäre</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Webinhalt</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Popup Fenster blockieren</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Plugins aktivieren</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>KlickToFlash benutzen</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Javascript aktivieren</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Cookies akzeptieren:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Nur von besuchten Seiten</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Ausnahmen...</translation>
    </message>
    <message>
        <source>Keep until:</source>
        <translation type="obsolete">Speichern bis:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>die Cookies ablaufen</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>das Programm beende</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>maximal 90 Tage</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Enable proxy</source>
        <translation type="obsolete">Proxy aktivieren</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="obsolete">Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Style Sheet:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="obsolete">Größe:</translation>
    </message>
    <message>
        <source>Default font:</source>
        <translation type="obsolete">Standardschrift:</translation>
    </message>
    <message>
        <source>Sans serif</source>
        <translation type="obsolete">Sans serif</translation>
    </message>
    <message>
        <source>Serif</source>
        <translation type="obsolete">Serif</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Jedes Mal nach Ziel fragen</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Hier speichern:</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Standard-Schriftart:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Auswahl...</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Tabs</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Neue erzeugte Tabs und Fenster selektieren</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Nachfragen, wenn mehrere Tabs geschlossen werden</translation>
    </message>
    <message>
        <source>Enable Images</source>
        <translation type="obsolete">Bilder anzeigen</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Beim Starten:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Meine Homepage zeigen</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Eine leere Seite zeigen</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Letzte Sitzung wiederherstellen</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Beim Beenden</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Startseite:</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Bilder anzeigen</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Cookies speichern bis:</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Seitenfremde Cookies verbieten</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Das Schließen mehrerer Tabs oder Fenster bestätigen</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Nur einen Schließen Button anzeigen, statt einen für jeden Tab</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Anwendung beenden wenn letztes Tab geschlossen wurde</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Öffnen von LInks</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Links die in einem neuen Fenster geöffnet werden sollen:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>In einem neuen aktiven Tab im aktuellen Fenster</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>In einem neuen Tab im aktiven Fenster</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Im aktuellen Tab</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Proxyserver verwenden</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Sicher)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (Unsicher)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Hostname:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Netzwerk-Cache aktivieren</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Maximale Größe:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Standardsuchmaschiene benutzen falls die vom Nutzer angegebene URL ungültig ist</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Verzeichnis auswählen...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>Gültigkeit einer Cookie Sitzung:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>Bis zum schließen des Browsers</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>1 Tag</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>2 Tage</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 Tage</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>7 Tage</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>30 Tage</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation>Autovervollständigung</translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>Autovervollständigungs Formulare:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Benutzernamen und Passwörter</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Editieren...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Anzeigen...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Neustart nötig</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>Die Netzwerk-Cache Konfiguration wurde geändert. Damit diese Änderung Effekt hat, muss der Browser neu gestartet werden.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>CSS Datei auswählen</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Ansicht</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">Zeilen &amp;Umbrechen</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Quelltext der Seite</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Quelltext der Seite %1</translation>
    </message>
</context>
<context>
    <name>SuggestionsTestNetworkReply</name>
    <message>
        <source>No Error</source>
        <translation>Kein Fehler</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">Neuer &amp;Tab</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Tab duplizieren</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Tab &amp;schließen</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>&amp;Andere Tabs schließen</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Tab neu laden</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Alle Tabs neu laden</translation>
    </message>
    <message>
        <source>Shift+Ctrl+T</source>
        <translation type="obsolete">Shift+Ctrl+T</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation>Tableiste zeigen</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Tableiste verbergen</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Neuer &amp;Tab</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Tab schließen</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Gespeicherte Tabs</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Laden %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Laden abgeschlossen</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Laden fehlgeschlagen</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translatorcomment>Not sure if the Key is the same in german</translatorcomment>
        <translation>Strg+]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translatorcomment>Not sure if the Key is the same in german</translatorcomment>
        <translation>Strg+[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Zuletzt geschlossene Tabs</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Alle Tabs als Lezeichen hinzufügen</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation type="obsolete">(Unbetitelt)</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Diese Seite wirklich schließen?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Die Seite wurde modifiziert. Wenn die Seite geschlossen wird gehen die Änderungen verloren.
Diese Seite wirklich schließen?</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Namenlos</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Google</source>
        <translation type="obsolete">Google</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>&apos;%1&apos; hinzufügen</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Keine vorherigen Suchvorgänge</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Letzte Suchvorgänge</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Letzte Suchvorgänge löschen</translation>
    </message>
</context>
<context>
    <name>TreeSortFilterProxyModelDialog</name>
    <message>
        <source>Dialog</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Fehler beim Laden von: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Beim Verbinden zu: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Überprüfen Sie die Adresse auf Fehler wie &lt;b&gt;ww&lt;/b&gt;.arora-browser.org statt &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">Falls die Adresse stimmt, versuchen Sie, die Netzwerkverbindung zu überprüfen.</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Falls die Adresse stimmt, versuchen Sie, die Netzwerkverbindung zu überprüfen.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Wenn Ihr Computer oder Ihr Netzwerk durch eine Firewall oder einen Proxy geschützt ist, stellen Sie sicher, dass der Browser auf das Netzwerk zugreifen darf.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Erneutes Senden einer POST Anfrage</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Um diese Seite anzeigen können, muss die Anfrage mit allen Daten erneut gesendet werden, was zu unerwartetem Verhalten der Seite führen kann, so könnte z.B. die selbe Aktion erneut ausgeführt werden. Möchten Sie trotzdem fortfahren?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>In einem neuen &amp;Fenster öffnen</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>In einem neuen &amp;Tab öffnen</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Lin&amp;k speichern</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Lesezeichen für diesen Link setzen</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>Linkadresse &amp;kopieren</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Bild in einem neuen &amp;Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Bild in einem neuen &amp;Tab öffnen</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>Bild &amp;speichern</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Bild &amp;kopieren</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Bildadresse &amp;kopieren</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Suchen mit...</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Zur Suchleiste hinzufügen</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Methode nicht unterstützt</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 Methode wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Suchmaschiene</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Wählen Sie die gewünschte Suchmaschiene</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Geben Sie einen Namen für die Suchmaschiene ein</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Bild unterdrücken</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Nicht gefunden</translation>
    </message>
</context>
</TS>
